==> jc-1.4.0.tar.gz: soot/jimple/internal/AbstractInstanceInvokeExpr.h <==
// public abstract class soot.jimple.internal.AbstractInstanceInvokeExpr

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class a0ee2217a7b698d3 soot_jimple_internal_AbstractInstanceInvokeExpr
// @dep_class 6b76cbc3f8fbbdb7 soot_jimple_internal_AbstractInvokeExpr

// header file dependencies
// @dep_header soot_jimple_internal_AbstractInvokeExpr

#include "soot/jimple/internal/AbstractInvokeExpr.h"

#ifndef _JC_soot_jimple_internal_AbstractInstanceInvokeExpr_H_
#define _JC_soot_jimple_internal_AbstractInstanceInvokeExpr_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_List$object;
struct _jc_soot_Value$object;
struct _jc_soot_ValueBox$object;

// Typedefs
typedef struct _jc_soot_jimple_internal_AbstractInstanceInvokeExpr$sub_refs	_jc_soot_jimple_internal_AbstractInstanceInvokeExpr$sub_refs;
typedef struct _jc_soot_jimple_internal_AbstractInstanceInvokeExpr$sub_nonrefs	_jc_soot_jimple_internal_AbstractInstanceInvokeExpr$sub_nonrefs;
typedef struct _jc_soot_jimple_internal_AbstractInstanceInvokeExpr$refs	_jc_soot_jimple_internal_AbstractInstanceInvokeExpr$refs;
typedef struct _jc_soot_jimple_internal_AbstractInstanceInvokeExpr$nonrefs	_jc_soot_jimple_internal_AbstractInstanceInvokeExpr$nonrefs;
typedef struct _jc_soot_jimple_internal_AbstractInstanceInvokeExpr$object	_jc_soot_jimple_internal_AbstractInstanceInvokeExpr$object;

typedef const struct _jc_soot_jimple_internal_AbstractInstanceInvokeExpr$vmethods	_jc_soot_jimple_internal_AbstractInstanceInvokeExpr$vmethods;
typedef const struct _jc_soot_jimple_internal_AbstractInstanceInvokeExpr$vtable	_jc_soot_jimple_internal_AbstractInstanceInvokeExpr$vtable;
typedef const struct _jc_soot_jimple_internal_AbstractInstanceInvokeExpr$vtype	_jc_soot_jimple_internal_AbstractInstanceInvokeExpr$vtype;

// Constructors
extern void _jc_soot_jimple_internal_AbstractInstanceInvokeExpr$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_internal_AbstractInstanceInvokeExpr$object *);

// Virtual methods
extern struct _jc_object *_jc_soot_jimple_internal_AbstractInstanceInvokeExpr$method$getBase$413b8e7231f9b918(_jc_env *, struct _jc_soot_jimple_internal_AbstractInstanceInvokeExpr$object *);
extern struct _jc_object *_jc_soot_jimple_internal_AbstractInstanceInvokeExpr$method$getBaseBox$8325e713cc78a03e(_jc_env *, struct _jc_soot_jimple_internal_AbstractInstanceInvokeExpr$object *);
extern struct _jc_object *_jc_soot_jimple_internal_AbstractInstanceInvokeExpr$method$getUseBoxes$8c22fb3c6dc4d01e(_jc_env *, struct _jc_soot_jimple_internal_AbstractInstanceInvokeExpr$object *);
extern void _jc_soot_jimple_internal_AbstractInstanceInvokeExpr$method$setBase$1cf9a9007c2e06ee(_jc_env *, struct _jc_soot_jimple_internal_AbstractInstanceInvokeExpr$object *, struct _jc_object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_internal_AbstractInstanceInvokeExpr$method_info$getBase$413b8e7231f9b918;
extern _jc_method _jc_soot_jimple_internal_AbstractInstanceInvokeExpr$method_info$getBaseBox$8325e713cc78a03e;
extern _jc_method _jc_soot_jimple_internal_AbstractInstanceInvokeExpr$method_info$getUseBoxes$8c22fb3c6dc4d01e;
extern _jc_method _jc_soot_jimple_internal_AbstractInstanceInvokeExpr$method_info$setBase$1cf9a9007c2e06ee;

// Virtual methods structure
struct _jc_soot_jimple_internal_AbstractInstanceInvokeExpr$vmethods {
	struct _jc_object	*(*getBase$413b8e7231f9b918)(_jc_env *, struct _jc_soot_jimple_internal_AbstractInstanceInvokeExpr$object *);
	struct _jc_object	*(*getBaseBox$8325e713cc78a03e)(_jc_env *, struct _jc_soot_jimple_internal_AbstractInstanceInvokeExpr$object *);
	struct _jc_object	*(*getUseBoxes$8c22fb3c6dc4d01e)(_jc_env *, struct _jc_soot_jimple_internal_AbstractInstanceInvokeExpr$object *);
	void	(*setBase$1cf9a9007c2e06ee)(_jc_env *, struct _jc_soot_jimple_internal_AbstractInstanceInvokeExpr$object *, struct _jc_object *);
};

// Vtable
struct _jc_soot_jimple_internal_AbstractInstanceInvokeExpr$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_internal_AbstractInvokeExpr$vmethods	soot_jimple_internal_AbstractInvokeExpr;
	_jc_soot_jimple_internal_AbstractInstanceInvokeExpr$vmethods	soot_jimple_internal_AbstractInstanceInvokeExpr;
};

// Vtype
struct _jc_soot_jimple_internal_AbstractInstanceInvokeExpr$vtype {
	_jc_type			type;
	_jc_soot_jimple_internal_AbstractInstanceInvokeExpr$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_internal_AbstractInstanceInvokeExpr$sub_refs {
	struct _jc_object	*baseBox;
};

// Reference instance fields (object)
struct _jc_soot_jimple_internal_AbstractInstanceInvokeExpr$refs {
    _jc_soot_jimple_internal_AbstractInstanceInvokeExpr$sub_refs	soot_jimple_internal_AbstractInstanceInvokeExpr;
    _jc_soot_jimple_internal_AbstractInvokeExpr$sub_refs	soot_jimple_internal_AbstractInvokeExpr;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_internal_AbstractInstanceInvokeExpr$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_internal_AbstractInstanceInvokeExpr$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_internal_AbstractInvokeExpr$sub_nonrefs	soot_jimple_internal_AbstractInvokeExpr;
    _jc_soot_jimple_internal_AbstractInstanceInvokeExpr$sub_nonrefs	soot_jimple_internal_AbstractInstanceInvokeExpr;
};

// Object instance structure
struct _jc_soot_jimple_internal_AbstractInstanceInvokeExpr$object {
	_jc_soot_jimple_internal_AbstractInstanceInvokeExpr$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_internal_AbstractInstanceInvokeExpr$vtype	*vtype;
	_jc_soot_jimple_internal_AbstractInstanceInvokeExpr$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_internal_AbstractInstanceInvokeExpr$vtype _jc_soot_jimple_internal_AbstractInstanceInvokeExpr$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_internal_AbstractInstanceInvokeExpr, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_internal_AbstractInstanceInvokeExpr$class_object;

#endif	/* _JC_soot_jimple_internal_AbstractInstanceInvokeExpr_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/internal/AbstractInstanceInvokeExpr.h <==
// public abstract class soot.jimple.internal.AbstractInstanceInvokeExpr

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class a0ee2217a7b698d3 soot_jimple_internal_AbstractInstanceInvokeExpr
// @dep_class 6b76cbc3f8fbbdb7 soot_jimple_internal_AbstractInvokeExpr

// header file dependencies
// @dep_header soot_jimple_internal_AbstractInvokeExpr

#include "soot/jimple/internal/AbstractInvokeExpr.h"

#ifndef _JC_soot_jimple_internal_AbstractInstanceInvokeExpr_H_
#define _JC_soot_jimple_internal_AbstractInstanceInvokeExpr_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_List$object;
struct _jc_soot_Value$object;
struct _jc_soot_ValueBox$object;

// Typedefs
typedef struct _jc_soot_jimple_internal_AbstractInstanceInvokeExpr$sub_refs	_jc_soot_jimple_internal_AbstractInstanceInvokeExpr$sub_refs;
typedef struct _jc_soot_jimple_internal_AbstractInstanceInvokeExpr$sub_nonrefs	_jc_soot_jimple_internal_AbstractInstanceInvokeExpr$sub_nonrefs;
typedef struct _jc_soot_jimple_internal_AbstractInstanceInvokeExpr$refs	_jc_soot_jimple_internal_AbstractInstanceInvokeExpr$refs;
typedef struct _jc_soot_jimple_internal_AbstractInstanceInvokeExpr$nonrefs	_jc_soot_jimple_internal_AbstractInstanceInvokeExpr$nonrefs;
typedef struct _jc_soot_jimple_internal_AbstractInstanceInvokeExpr$object	_jc_soot_jimple_internal_AbstractInstanceInvokeExpr$object;

typedef const struct _jc_soot_jimple_internal_AbstractInstanceInvokeExpr$vmethods	_jc_soot_jimple_internal_AbstractInstanceInvokeExpr$vmethods;
typedef const struct _jc_soot_jimple_internal_AbstractInstanceInvokeExpr$vtable	_jc_soot_jimple_internal_AbstractInstanceInvokeExpr$vtable;
typedef const struct _jc_soot_jimple_internal_AbstractInstanceInvokeExpr$vtype	_jc_soot_jimple_internal_AbstractInstanceInvokeExpr$vtype;

// Constructors
extern void _jc_soot_jimple_internal_AbstractInstanceInvokeExpr$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_internal_AbstractInstanceInvokeExpr$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_object *_jc_soot_jimple_internal_AbstractInstanceInvokeExpr$method$getBase$413b8e7231f9b918(_jc_env *, struct _jc_soot_jimple_internal_AbstractInstanceInvokeExpr$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_soot_jimple_internal_AbstractInstanceInvokeExpr$method$getBaseBox$8325e713cc78a03e(_jc_env *, struct _jc_soot_jimple_internal_AbstractInstanceInvokeExpr$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_soot_jimple_internal_AbstractInstanceInvokeExpr$method$getUseBoxes$8c22fb3c6dc4d01e(_jc_env *, struct _jc_soot_jimple_internal_AbstractInstanceInvokeExpr$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_internal_AbstractInstanceInvokeExpr$method$setBase$1cf9a9007c2e06ee(_jc_env *, struct _jc_soot_jimple_internal_AbstractInstanceInvokeExpr$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_internal_AbstractInstanceInvokeExpr$method_info$getBase$413b8e7231f9b918;
extern _jc_method _jc_soot_jimple_internal_AbstractInstanceInvokeExpr$method_info$getBaseBox$8325e713cc78a03e;
extern _jc_method _jc_soot_jimple_internal_AbstractInstanceInvokeExpr$method_info$getUseBoxes$8c22fb3c6dc4d01e;
extern _jc_method _jc_soot_jimple_internal_AbstractInstanceInvokeExpr$method_info$setBase$1cf9a9007c2e06ee;

// Virtual methods structure
struct _jc_soot_jimple_internal_AbstractInstanceInvokeExpr$vmethods {
	struct _jc_object	*(*getBase$413b8e7231f9b918)(_jc_env *, struct _jc_soot_jimple_internal_AbstractInstanceInvokeExpr$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*getBaseBox$8325e713cc78a03e)(_jc_env *, struct _jc_soot_jimple_internal_AbstractInstanceInvokeExpr$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*getUseBoxes$8c22fb3c6dc4d01e)(_jc_env *, struct _jc_soot_jimple_internal_AbstractInstanceInvokeExpr$object *) _JC_JCNI_ATTR;
	void	(*setBase$1cf9a9007c2e06ee)(_jc_env *, struct _jc_soot_jimple_internal_AbstractInstanceInvokeExpr$object *, struct _jc_object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_internal_AbstractInstanceInvokeExpr$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_internal_AbstractInvokeExpr$vmethods	soot_jimple_internal_AbstractInvokeExpr;
	_jc_soot_jimple_internal_AbstractInstanceInvokeExpr$vmethods	soot_jimple_internal_AbstractInstanceInvokeExpr;
};

// Vtype
struct _jc_soot_jimple_internal_AbstractInstanceInvokeExpr$vtype {
	_jc_type			type;
	_jc_soot_jimple_internal_AbstractInstanceInvokeExpr$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_internal_AbstractInstanceInvokeExpr$sub_refs {
	struct _jc_object	*baseBox;
};

// Reference instance fields (object)
struct _jc_soot_jimple_internal_AbstractInstanceInvokeExpr$refs {
    _jc_soot_jimple_internal_AbstractInstanceInvokeExpr$sub_refs	soot_jimple_internal_AbstractInstanceInvokeExpr;
    _jc_soot_jimple_internal_AbstractInvokeExpr$sub_refs	soot_jimple_internal_AbstractInvokeExpr;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_internal_AbstractInstanceInvokeExpr$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_internal_AbstractInstanceInvokeExpr$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_internal_AbstractInvokeExpr$sub_nonrefs	soot_jimple_internal_AbstractInvokeExpr;
    _jc_soot_jimple_internal_AbstractInstanceInvokeExpr$sub_nonrefs	soot_jimple_internal_AbstractInstanceInvokeExpr;
};

// Object instance structure
struct _jc_soot_jimple_internal_AbstractInstanceInvokeExpr$object {
	_jc_soot_jimple_internal_AbstractInstanceInvokeExpr$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_internal_AbstractInstanceInvokeExpr$vtype	*vtype;
	_jc_soot_jimple_internal_AbstractInstanceInvokeExpr$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_internal_AbstractInstanceInvokeExpr$vtype _jc_soot_jimple_internal_AbstractInstanceInvokeExpr$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_internal_AbstractInstanceInvokeExpr, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_internal_AbstractInstanceInvokeExpr$class_object;

#endif	/* _JC_soot_jimple_internal_AbstractInstanceInvokeExpr_H_ */
